Skip to contents

A bundled dataset for the functional data analysis tutorial.

Format

A list with three components:

weather_daily

Daily weather curves for multiple simulated sites, using the daily_<statistic>_<variable> naming style used in the window-pane tutorials.

assessments

One binary disease assessment per site with wm and wm_class.

variable_specs

A data frame of FDA variable names and display labels.

Details

The data were created from the package's simulation functions and then bundled so the FDA vignette can focus on interpretation, smoothing, interval testing, and feature extraction.