Demo Data for Functional Data Analysis Workflows
fda_demo_data.RdA bundled dataset for the functional data analysis tutorial.
Format
A list with three components:
- weather_daily
Daily weather curves for multiple simulated sites, using the
daily_<statistic>_<variable>naming style used in the window-pane tutorials.- assessments
One binary disease assessment per site with
wmandwm_class.- variable_specs
A data frame of FDA variable names and display labels.