Summarise Weather Inside a Single Window
summarise_weather_window.RdComputes a small set of epidemiology-friendly summaries from a subset of a weather time series.
Arguments
- weather
A validated weather data frame.
- weather_cols
Character vector of weather columns to summarize. If named, the names are used in the output feature names.
- temp_col
Name of the temperature column.
- rh_col
Name of the relative humidity column.
- rain_col
Name of the rainfall column.
- leaf_wetness_col
Name of the leaf wetness column.
- statistics
Summary statistics to compute. Use a character vector to apply the same statistics to all
weather_cols, such asc("mean", "sd", "IQR"). Use a named list to choose statistics by variable or to provide custom named functions. Use.conditionsfor multivariable condition summaries such ascount_when(temp >= 18 & rh >= 90). Threshold summaries should be specified here, for examplelist(rh = list(days_at_or_above_90 = count_at_or_above(90))).