Demo Data for Window-Pane Workflows
window_pane_demo_data.RdA bundled dataset for the getting-started, window-pane, and feature-screening tutorials.
Format
A list with three components:
- weather
Daily weather data for multiple simulated sites, all with the same time-series length and at least 30 days before planting.
- weather_hourly
Hourly weather data used to create
weather.- assessments
One disease assessment per site, including
assessment_time,planting_time, anddisease_intensity.
Details
The data were generated with simulate_weather_series and
simulate_assessment_data and then saved as package data so the
main workflow tutorials can begin directly with analysis.